Apply a function rowwise to two same length vectors, e.g. comparison functions. Optionally apply wrap functions to each item before the apply function. Functions can also be function names (e.g. "sum" or "+").
Arguments
- vec1
Atomic vector 1.
- vec2
Atomic vector 2.
- apply_fun
The function that should be applied to both elements from
vec1andvec2at the same index. Can be a function or a function name.- wrap_fun_vec1
Optionally, a function that shall be applied to every
vec1element before applyingapply_fun. Can be a function or a function name.- wrap_fun_vec2
Optioanlly, a function that shall be applied to every
vec2element before applyingapply_fun. Can be a function or a function name.